==> connect-app-cache-0.0.4.tgz: package/lib/app-cache.js <==
/*!
 * connect - app-cache
 * Copyright(c) 2011 Enginimation Studio
 * MIT Licensed
 */

// Cached version of the app cache file
var appCache;

module.exports=function appCache(fileName, filePath, options){
  var options = options  || {},
     fileName = fileName || 'app.mf',
     filePath = filePath || __dirname + '/../public/'+fileName,
     // max age. Default to one day
     maxAge   = options.maxAge || 86400000;
     console.log("enetered app_cached")
     return function appCache(req, res, next){
        if (fileName===req.url){
            console.log("1 branch")
            if(appCache){
                res.writeHead(200,appCache.headers);
                res.end(appCache.body);
            }
            else{
                fs.readFile(filePath,function(err,buf){
                    if(err) return next(err);
                    appCache={
                        headers:{
                            'Content-Type'  : 'text/cache-manifest',
                            'Content-Length': buf.length,
                            'ETag'          : '"' + utils.md5(buf) + '"',          // do we need this caching?
                            'Cache-Control' : 'public, max-age=' + (maxAge / 1000) // do we need this caching?
                        },
                        body: buf
                    };
                    res.writeHead(200,appCache.headers);
                    res.end(appCache.body);
                });
            }
        }
        else{
            console.log("2 branch")
            next();
        }
     };
};

==> connect-app-cache-0.0.6.tgz: package/lib/app-cache.js <==
/*!
 * connect - app-cache
 * Copyright(c) 2011 Enginimation Studio
 * MIT Licensed
 */

// Cached version of the app cache file
var appCache;

module.exports=function appCache(fileName, filePath, options){
  var options = options  || {},
     fileName = fileName || 'app.mf',
     filePath = filePath || __dirname + '/../public/'+fileName,
     // max age. Default to one day
     maxAge   = options.maxAge || 86400000;
     console.log("enetered app_cached")
     return function appCache(req,res,next){
        console.log('req urk',req.url);
        if ('/'+fileName===req.url){
            console.log("1 branch")
            if(appCache){
                res.writeHead(200,appCache.headers);
                res.end(appCache.body);
            }
            else{
                console.log("FIle path",filePath)
                fs.readFile(filePath,function(err,buf){
                    if(err) return next(err);
                    appCache={
                        headers:{
                            'Content-Type'  : 'text/cache-manifest',
                            'Content-Length': buf.length,
                            'ETag'          : '"' + utils.md5(buf) + '"',          // do we need this caching?
                            'Cache-Control' : 'public, max-age=' + (maxAge / 1000) // do we need this caching?
                        },
                        body: buf
                    };
                    res.writeHead(200,appCache.headers);
                    res.end(appCache.body);
                });
            }
        }
        else{
            console.log("2 branch")
            next();
        }
     };
};
